guile-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Guile-commits] GNU Guile branch, wip-r6rs-libraries, updated. release_1


From: Julian Graham
Subject: [Guile-commits] GNU Guile branch, wip-r6rs-libraries, updated. release_1-9-8-88-ge084d7a
Date: Sat, 27 Mar 2010 15:39:33 +0000

This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "GNU Guile".

http://git.savannah.gnu.org/cgit/guile.git/commit/?id=e084d7a24d0b431750044512379d87be30a1fdff

The branch, wip-r6rs-libraries has been updated
       via  e084d7a24d0b431750044512379d87be30a1fdff (commit)
      from  d51ffe965183af1c63ba922ede1e3de8686c515b (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit e084d7a24d0b431750044512379d87be30a1fdff
Author: Julian Graham <address@hidden>
Date:   Sat Mar 27 11:39:28 2010 -0400

    Implementation for the R6RS (rnrs r5rs) library.
    
    * module/Makefile.am: Add rnrs/6/r5rs.scm to RNRS_SOURCES.
    * module/rnrs/6/r5rs.scm: New file.

-----------------------------------------------------------------------

Summary of changes:
 module/Makefile.am                       |    1 +
 module/rnrs/6/{programs.scm => r5rs.scm} |   20 ++++++++++++++++----
 2 files changed, 17 insertions(+), 4 deletions(-)
 copy module/rnrs/6/{programs.scm => r5rs.scm} (68%)

diff --git a/module/Makefile.am b/module/Makefile.am
index 52ca7e8..2dcba79 100644
--- a/module/Makefile.am
+++ b/module/Makefile.am
@@ -264,6 +264,7 @@ RNRS_SOURCES =                                      \
   rnrs/6/hashtables.scm                                \
   rnrs/6/lists.scm                             \
   rnrs/6/programs.scm                          \
+  rnrs/6/r5rs.scm                              \
   rnrs/6/sorting.scm                           \
   rnrs/6/syntax-case.scm                       \
   rnrs/6/unicode.scm                           \
diff --git a/module/rnrs/6/programs.scm b/module/rnrs/6/r5rs.scm
similarity index 68%
copy from module/rnrs/6/programs.scm
copy to module/rnrs/6/r5rs.scm
index 4daa781..fefda05 100644
--- a/module/rnrs/6/programs.scm
+++ b/module/rnrs/6/r5rs.scm
@@ -1,4 +1,4 @@
 ;;; programs.scm --- The R6RS process management library
 
 ;;      Copyright (C) 2010 Free Software Foundation, Inc.
 ;;
@@ -17,6 +17,18 @@
 ;; Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 
-(library (rnrs programs (6))
-  (export command-line exit)
-  (import (only (guile) command-line exit)))
+(library (rnrs r5rs (6))
+  (export exact->inexact inexact->exact 
+
+         quotient remainder modulo 
+
+         delay force 
+
+         null-environment scheme-report-environment)
+  (import (only (guile) exact->inexact inexact->exact
+                       
+                       quotient remainder modulo
+                       
+                       delay force
+
+                       null-environment scheme-report-environment)))
@@ -1,4 +1,4 @@
-;;; programs.scm --- The R6RS process management library
+;;; r5rs.scm --- The R6RS / R5RS compatibility library
 
 ;;      Copyright (C) 2010 Free Software Foundation, Inc.


hooks/post-receive
-- 
GNU Guile




reply via email to

[Prev in Thread] Current Thread [Next in Thread]